@@ -1695,7 +1695,7 @@ def cli(
                         d_2000 = 0
                         d_3000 = 0
 
-                        for account, distance in user_df.itertuples(index=False):
+                        for account, distance, longitude, latitude, filetime in user_df.itertuples(index=False):
                             account = int(account)
                             my_user = await client.get_entity(PeerUser(account))
                             user_id = my_user.id
